#ifndef _QUERY_DIALOG_H_
#define _QUERY_DIALOG_H_

#include <libhildondesktop/libhildondesktop.h>
#include <gtk/gtk.h>

typedef void (*ShowSettingsDialogCb)(HDHomePluginItem *, GtkWindow *);

void query_dialog_show(HDHomePluginItem *hdhpi, GtkTreeModel *tm, ShowSettingsDialogCb ssdcb);
GtkWidget *query_dialog_make_tv(GtkTreeModel *tm, GtkWidget **p_tv);

#endif /* !_QUERY_DIALOG_H_ */
